
/*
 * We maintain the compatibility list for a class. We just want
 * to know whether a class is compatible with (derived from) any
 * other class.
 * We need this knowledge to decide whether an object can be
 * passed to a function that expects a different type, which is
 * only possible if the object is *compatible* with (derived
 * from) that type.
 * For each class, we store a tree of the info structures of
 * *all* parent classes, including indirect parents.
 *
 * TclObj_BuildComptree() initializes the tree and traverses the
 * list of parents recursively and adds each parent.
 *
 * TclObj_IsCompatible() decides whether the given type (represented
 * by its information structure) is compatible with the type in the
 * other parameter, represented either by its name or its type
 * identification.
 *
 * TclObj_DumpComptree() produces a list of all compatible types
 * and adds them to the current result of interp.
 *
 * There are yet no functions to delete the structures.
 *
 * $Id: compat.h,v 1.2 1996/11/28 15:12:04 fp Exp $
 */

#ifndef __TCLOBJ_COMPAT_H__
#define __TCLOBJ_COMPAT_H__

#include <tcl.h>
#include "tclobj.h"

/*
 * compatibility tree of a class, sorted by info->ident
 */

typedef struct _TclObj_Comptree {
  const TclObj_Info *info;
  struct _TclObj_Comptree *left, *right;
} TclObj_Comptree;


int			TclObj_BuildComptree	(Tcl_Interp *,
						 TclObj_Info *);

int			TclObj_IsCompatible	(Tcl_Interp *,
						 const TclObj_Info *,
						 unsigned long);

int			TclObj_IsCompatible	(Tcl_Interp *,
						 const TclObj_Info *,
						 const char *);

int			TclObj_DumpComptree	(Tcl_Interp *,
						 const TclObj_Info *);

#endif
